Author: danielsh
Date: Fri Nov 22 23:35:17 2013
New Revision: 1544711

URL: http://svn.apache.org/r1544711
Log:
* subversion/mod_dav_svn/mod_dav_svn.c
  (dav_svn__translate_name): Change the prefix from "svn:/" to "dav_svn:/" for
    consistency with mod_proxy's precedent and for avoidance of confusion with
    the "svn://" URL scheme.  (As the docstring points out, these paths can
    end up in admin logs.)

Modified:
    subversion/trunk/subversion/mod_dav_svn/mod_dav_svn.c

Modified: subversion/trunk/subversion/mod_dav_svn/mod_dav_svn.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/mod_dav_svn/mod_dav_svn.c?rev=1544711&r1=1544710&r2=1544711&view=diff
==============================================================================
--- subversion/trunk/subversion/mod_dav_svn/mod_dav_svn.c (original)
+++ subversion/trunk/subversion/mod_dav_svn/mod_dav_svn.c Fri Nov 22 23:35:17 
2013
@@ -1097,7 +1097,8 @@ static int dav_svn__handler(request_rec 
 
 /* Fill the filename on the request with a bogus path since we aren't serving
  * a file off the disk.  This means that <Directory> blocks will not match and
- * that %f in logging formats will show as "svn:/path/to/repo/path/in/repo". */
+ * %f in logging formats will show as "dav_svn:/path/to/repo/path/in/repo".
+ */
 static int dav_svn__translate_name(request_rec *r)
 {
   const char *fs_path, *repos_basename, *repos_path;
@@ -1146,7 +1147,7 @@ static int dav_svn__translate_name(reque
   if (repos_path && '/' == repos_path[0] && '\0' == repos_path[1])
     repos_path = NULL;
 
   /* Combine 'svn:', fs_path and repos_path to produce the bogus path we're
    * placing in r->filename.  We can't use our standard join helpers such
    * as svn_dirent_join.  fs_path is a dirent and repos_path is a fspath
    * (that can be trivially converted to a relpath by skipping the leading
@@ -1154,7 +1155,7 @@ static int dav_svn__translate_name(reque
    * repository is 'trunk/c:hi' this results in a non canonical dirent on
    * Windows. Instead we just cat them together. */
   r->filename = apr_pstrcat(r->pool,
-                            "svn:", fs_path, repos_path, SVN_VA_NULL);
+                            "dav_svn:", fs_path, repos_path, SVN_VA_NULL);
 
   /* Leave a note to ourselves so that we know not to decline in the
    * map_to_storage hook. */
@@ -1146,7 +1147,7 @@ static int dav_svn__translate_name(reque
     repos_path = NULL;
 
-  /* Combine 'svn:', fs_path and repos_path to produce the bogus path we're
+  /* Combine 'dav_svn:', fs_path and repos_path to produce the bogus path we're
    * placing in r->filename.  We can't use our standard join helpers such
    * as svn_dirent_join.  fs_path is a dirent and repos_path is a fspath


Reply via email to